import Vue from 'vue'
import Router from 'vue-router'

const _import = require('./_import_' + process.env.NODE_ENV)
// in development env not use Lazy Loading,because Lazy Loading too many pages will cause webpack hot update too slow.so only in production use Lazy Loading

/* layout */
import Layout from '../views/layout/Layout'
import {setMenu} from '@/utils/helper'
// console.log("MEnu::",getMenu())
Vue.use(Router)

/**
 * icon : the icon show in the sidebar
 * hidden : if `hidden:true` will not show in the sidebar
 * redirect : if `redirect:noredirect` will not redirct in the levelbar
 * noDropdown : if `noDropdown:true` will not has submenu in the sidebar
 * meta : `{ role: ['admin'] }`  will control the page role
 **/
export const constantRouterMap = [
  {path: '/login', component: _import('login/index'), hidden: true},
  {path: '/register', component: _import('register/index'), hidden: true},
  {path: '/404', component: _import('404'), hidden: true},
  {
    path: '/',
    beforeEnter: (to, from, next) => {
      setMenu(1)
      next()
    },
    component: Layout,
    redirect: '/dashboard',
    name: '首页',
    hidden: true,
    children: [{path: 'dashboard', component: _import('dashboard/index')}]
  }
]

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({y: 0}),
  routes: constantRouterMap
})
export const asyncRouterMap = [
  {
    path: '/marketing/group',
    beforeEnter: (to, from, next) => {
      setMenu(1)
      next()
    },
    type: 1,
    component: Layout,
    redirect: 'noredirect',
    name: '集团管理',
    icon: 'jituan',
    meta: {role: ['集团', '集团添加', '集团修改', '集团支付账号', '集团添加支付渠道', '集团修改支付渠道', '集团支付营销', '集团支付营销添加', ' 集团支付营销修改']},
    children: [
      {
        path: 'manage/index',
        name: '集团',
        component: _import('marketing/group/manage/index'),
        meta: {role: ['集团']}
      },
      {
        path: 'manage/add',
        name: '集团添加',
        component: _import('marketing/group/manage/add'),
        hidden: true,
        meta: {role: ['集团添加']}
      },
      {
        path: 'manage/update/:id',
        name: '集团修改',
        component: _import('marketing/group/manage/update'),
        hidden: true,
        meta: {role: ['集团修改']}
      },
      {
        path: 'pay/index',
        name: '集团支付账号',
        component: _import('marketing/group/pay/index'),
        meta: {role: ['集团支付账号']}
      },
      {
        path: 'pay/add',
        name: '添加支付渠道',
        component: _import('marketing/group/pay/add'),
        hidden: true,
        meta: {role: ['集团添加支付渠道']}
      },
      {
        path: 'pay/update/:id',
        name: '修改支付渠道',
        component: _import('marketing/group/pay/update'),
        hidden: true,
        meta: {role: ['集团修改支付渠道']}
      },
      {
        path: 'pay/promotion/index',
        name: '集团支付营销',
        component: _import('marketing/group/pay/promotionIndex'),
        meta: {role: ['集团支付营销']}
      },
      {
        path: 'pay/promotion/add',
        name: '集团支付营销添加',
        component: _import('marketing/group/pay/promotionAdd'),
        hidden: true,
        meta: {role: ['集团支付营销']}
      },
      {
        path: 'pay/promotion/update/:id',
        name: '集团支付营销修改',
        component: _import('marketing/group/pay/promotionUpdate'),
        hidden: true,
        meta: {role: ['集团支付营销']}
      }
    ]
  },
  {
    path: '/marketing/shop',
    beforeEnter: (to, from, next) => {
      setMenu(1)
      next()
    },
    type: 1,
    component: Layout,
    redirect: 'noredirect',
    name: '门店管理',
    icon: 'shop',
    meta: {role: ['门店', '门店添加', '门店修改', '门店详情', '门店设备编辑', '门店支付渠道', '门店支付渠道添加', '门店支付渠道修改', '门店支付营销', '门店支付营销添加', ' 门店支付营销修改', '餐桌']},
    children: [
      {
        path: 'store/index',
        name: '门店',
        meta: {role: ['门店']},
        component: _import('marketing/shop/store/index')
      },
      {
        path: 'store/add',
        name: '门店添加',
        hidden: true,
        meta: {role: ['门店添加']},
        component: _import('marketing/shop/store/add')
      },
      {
        path: 'store/update/:id',
        name: '门店修改',
        hidden: true,
        meta: {role: ['门店修改']},
        component: _import('marketing/shop/store/update')
      },
      {
        path: 'store/show/:id',
        name: '门店详情',
        hidden: true,
        meta: {role: ['门店详情']},
        component: _import('marketing/shop/store/update')
      },
      {
        path: 'store/mac/:id',
        name: '设备编辑',
        hidden: true,
        component: _import('marketing/shop/store/mac'),
        meta: {role: ['门店设备编辑']}
      },
      // {
      //     path: 'commodity/index',
      //     name: '商品管理',
      //     component: _import('marketing/shop/commodity/index'),
      //     meta: {role: ['admin', 'user']}
      // },
      // {
      //     path: 'commodity/add',
      //     name: '商品添加',
      //     hidden: true,
      //     component: _import('marketing/shop/commodity/add'),
      //     meta: {role: ['admin', 'user']}
      // },
      // {
      //     path: 'commodity/update/:id',
      //     name: '商品修改',
      //     hidden: true,
      //     component: _import('marketing/shop/commodity/update'),
      //     meta: {role: ['admin', 'user']}
      // },
      // {
      //     path: 'activity/index',
      //     name: '门店活动设定',
      //     component: _import('marketing/shop/activity/index'),
      //     meta: {role: ['admin', 'user']}
      // },
      // {
      //     path: 'activity/add',
      //     name: '门店活动设定添加',
      //     hidden: true,
      //     component: _import('marketing/shop/activity/add'),
      //     meta: {role: ['admin', 'user']}
      // },
      // {
      //     path: 'activity/update/:id',
      //     name: '门店活动设定修改',
      //     hidden: true,
      //     component: _import('marketing/shop/activity/update'),
      //     meta: {role: ['admin', 'user']}
      // },
      {
        path: 'paychannel/index',
        name: '门店支付渠道',
        component: _import('marketing/group/pay/index'),
        meta: {role: ['门店支付渠道']}
      },
      {
        path: 'paychannel/add',
        name: '门店支付渠道添加',
        hidden: true,
        component: _import('marketing/group/pay/add'),
        meta: {role: ['门店支付渠道添加']}
      },
      {
        path: 'paychannel/update/:id',
        name: '门店支付渠道修改',
        hidden: true,
        component: _import('marketing/group/pay/update'),
        meta: {role: ['门店支付渠道修改']}
      },
      {
        path: 'paychannel/promotion/index',
        name: '门店支付营销',
        component: _import('marketing/group/pay/promotionIndex'),
        meta: {role: ['门店支付营销']}
      },
      {
        path: 'paychannel/promotion/add',
        name: '门店支付营销添加',
        component: _import('marketing/group/pay/promotionAdd'),
        hidden: true,
        meta: {role: ['门店支付营销']}
      },
      {
        path: 'paychannel/promotion/update/:id',
        name: '门店支付营销修改',
        component: _import('marketing/group/pay/promotionUpdate'),
        hidden: true,
        meta: {role: ['门店支付营销']}
      },
      {
        path: 'table',
        name: '餐桌',
        component: _import('marketing/shop/table/index'),
        meta: {role: ['餐桌']}
      },
      {
        path: 'tableGroup',
        name: '桌分组管理',
        hidden: true,
        component: _import('marketing/shop/table/tableGroup'),
      }
    ]
  },
  {
    path: '/marketing/adv',
    beforeEnter: (to, from, next) => {
      setMenu(1)
      next()
    },
    type: 1,
    component: Layout,
    redirect: 'noredirect',
    name: '广告管理',
    icon: 'zujian',
    meta: {role: ['广告资源管理', '广告资源添加', '广告策略管理', '广告策略添加']},
    children: [
      {
        path: 'resource/index',
        name: '广告资源管理',
        component: _import('marketing/adv/resource/index'),
        meta: {role: ['广告资源管理']}
      },
      {
        path: 'resource/add',
        name: '广告资源添加',
        component: _import('marketing/adv/resource/add'),
        hidden: true,
        meta: {role: ['广告资源添加']}
      },
      {
        path: 'strategy/index',
        name: '广告策略管理',
        component: _import('marketing/adv/strategy/index'),
        meta: {role: ['广告策略管理']}
      },
      {
        path: 'strategy/add',
        name: '广告策略添加',
        component: _import('marketing/adv/strategy/add'),
        hidden: true,
        meta: {role: ['广告策略添加']}
      }
    ]
  },

  {
    path: '/marketing/member',
    beforeEnter: (to, from, next) => {
      setMenu(1)
      next()
    },
    type: 1,
    component: Layout,
    redirect: 'noredirect',
    name: '会员',
    icon: 'people',
    meta: {role: ['会员管理', '会员等级管理', '会员详情', '会员交易历史']},
    children: [
      {
        path: 'resource/index',
        name: '会员管理',
        component: _import('marketing/member/index'),
        meta: {role: ['会员管理']}
      },
      {
        path: 'grade',
        name: '会员等级管理',
        component: _import('marketing/member/grade'),
        meta: {role: ['会员等级管理']}

      },
      {
        path: 'resource/info/:id',
        name: '会员详情',
        component: _import('marketing/member/info'),
        hidden: true,
        meta: {role: ['会员详情']}
      },
      {
        path: 'resource/history/:id',
        name: '会员交易历史',
        component: _import('marketing/member/history'),
        hidden: true,
        meta: {role: ['会员交易历史']}
      }
    ]
  },
  {
    path: '/accounts/manage',
    beforeEnter: (to, from, next) => {
      setMenu(2)
      next()
    },
    type: 2,
    component: Layout,
    icon: 'tubiao',
    redirect: '/accounts/manage/index',
    // name: '帐号管理',
    meta: {role: ['帐号管理', '帐号添加', '帐号修改', '权限配置']},
    noDropdown: true,
    children: [
      {
        path: 'index',
        name: '帐号管理',
        component: _import('accounts/manage/index'),
        meta: {role: ['帐号管理']}
      },
      {
        path: 'add',
        name: '帐号添加',
        hidden: true,
        component: _import('accounts/manage/add'),
        meta: {role: ['帐号添加']}
      },
      {
        path: 'update/:id',
        name: '帐号修改',
        hidden: true,
        component: _import('accounts/manage/update'),
        meta: {role: ['帐号修改']}
      },
      {
        path: 'permissions/:id',
        name: '权限配置',
        hidden: true,
        component: _import('accounts/manage/permissions'),
        meta: {role: ['权限配置']}
      }
    ]
  },
  {
    name: '软件版本管理 ',
    path: '/ota/version',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    meta: {role: ['版本列表', '上传新版本']},
    children: [
      {path: 'index', name: '版本列表', component: _import('ota/version/index'), meta: {role: ['版本列表']}},
      {path: 'add', name: '上传新版本', component: _import('ota/version/add'), meta: {role: ['上传新版本']}}
    ]
  },
  {
    name: '设备mac管理 ',
    path: '/ota/mac',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    meta: {role: ['设备列表', '设备导入', '设备添加', '设备修改']},
    children: [
      {path: 'index', name: '设备列表', component: _import('ota/mac/index'), meta: {role: ['设备列表']}}, // sid为门店id
      {path: 'import', name: '设备导入', component: _import('ota/mac/import'), meta: {role: ['设备导入']}},
      {path: 'add', name: '设备添加', component: _import('ota/mac/add'), meta: {role: ['设备添加']}},
      {path: 'edit/:id', name: '设备修改', hidden: true, component: _import('ota/mac/edit'), meta: {role: ['设备修改']}}
    ]
  },
  {
    name: '升级策略管理',
    path: '/ota/upgrade',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    meta: {role: ['升级策略列表', '升级策略添加']},
    children: [
      {path: 'index', name: '升级策略列表', component: _import('ota/upgrade/index'), meta: {role: ['升级策略列表']}},
      {path: 'add', name: '升级策略添加', component: _import('ota/upgrade/add'), meta: {role: ['升级策略添加']}}
    ]
  },
  {
    name: '设备状态查询',
    path: '/ota/deviceStatus',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    meta: {role: ['设备状态', '升级历史']},
    // noDropdown: true,
    children: [
      {path: 'index', name: '设备状态', component: _import('ota/deviceStatus/index'), meta: {role: ['设备状态']}},
      {path: 'history', name: '升级历史', component: _import('ota/deviceStatus/history'), meta: {role: ['升级历史']}}
    ]
  },
  {
    name: '配置策略管理',
    path: '/ota/configure',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    meta: {role: ['配置策略列表', '配置策略添加']},
    children: [
      {path: 'index', name: '配置策略列表', component: _import('ota/configure/index'), meta: {role: ['配置策略列表']}},
      {path: 'add', name: '配置策略添加', component: _import('ota/configure/add'), meta: {role: ['配置策略添加']}}
    ]
  },
  {
    name: 'app管理',
    path: '/ota/app',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    // meta: { role: ['配置策略列表', '配置策略添加'] },
    children: [
      {path: 'index', name: 'app查询', component: _import('ota/app/index')},
      {path: 'apk', name: 'apk版本', component: _import('ota/app/apk')},
      {path: 'addStrategy', name: '添加app策略', component: _import('ota/app/strategyAdd')},
      {path: 'strategy', name: 'app策略查询', component: _import('ota/app/strategyIndex')},
    ]
  },
  {
    name: '打印机管理',
    path: '/printer',
    beforeEnter: (to, from, next) => {
      setMenu(3)
      next()
    },
    type: 3,
    component: Layout,
    icon: 'table',
    redirect: 'noredirect',
    // noDropdown: true,
    meta: { role: ['打印机列表', '添加打印机', '添加中转设备', '更新打印机', '更新中转设备'] },
    children: [
      {path: 'index', name: '打印机列表', component: _import('ota/printer/index')},
      {path: 'addPrinter', name: '添加打印机', hidden: true, component: _import('ota/printer/addPrinter')},
      {path: 'addTransfer', name: '添加中转设备', hidden: true, component: _import('ota/printer/addTransfer')},
      {path: 'updatePrinter/:id', name: '更新打印机', hidden: true, component: _import('ota/printer/addPrinter')},
      {path: 'updateTransfer/:id', name: '更新中转设备', hidden: true, component: _import('ota/printer/addTransfer')}
    ]
  },
  {
    path: '/transaction/order',
    beforeEnter: (to, from, next) => {
      setMenu(4)
      next()
    },
    type: 4,
    component: Layout,
    icon: 'tubiao',
    redirect: 'noredirect',
    // noDropdown: true,
    name: '交易管理',
    meta: {role: ['订单管理', '交易统计', '交易流水', '交易日期统计', '交易占比统计', '门店支付方式交易统计']},
    children: [
      {
        path: 'index',
        name: '订单管理',
        component: _import('transaction/order/index'),
        hidden: true,
        meta: {role: ['订单管理']}
      },
      {
        path: 'statistics',
        name: '交易统计',
        component: _import('transaction/order/statistics'),
        hidden: true,
        meta: {role: ['交易统计']}
      },
      {
        path: 'flow',
        name: '交易流水',
        component: _import('transaction/order/flow'),
        hidden: true,
        meta: {role: ['交易流水']}
      },
      {
        path: 'datestatistics',
        name: '交易日期统计',
        component: _import('transaction/order/datestatistics'),
        meta: {role: ['交易日期统计']}
      },
      {
        path: 'ratiostatistics',
        name: '交易占比统计',
        component: _import('transaction/order/ratiostatistics'),
        meta: {role: ['交易占比统计']}
      },
      {
        path: 'shopPaymentTypeStatistics',
        name: '门店支付方式交易统计',
        component: _import('transaction/order/shopPaymentTypeStatistics'),
        meta: {role: ['门店支付方式交易统计']}
      }
    ]
  },
  {
    path: '/stock/goods',
    beforeEnter: (to, from, next) => {
      setMenu(5)
      next()
    },
    type: 5,
    component: Layout,
    icon: 'tubiao',
    name: '商品管理',
    meta: {role: ['商品分类', '商品列表', '商品添加', '商品修改', '商品审核']},
    children: [
      {
        path: 'type',
        name: '商品分类',
        component: _import('stock/goods/type'),
      },
      {
        path: 'taste',
        name: '商品口味',
        component: _import('stock/goods/taste'),
      },

      {
        path: 'index',
        name: '商品列表',
        component: _import('stock/goods/index'),
        meta: {role: ['商品列表']}
      },
      {
        path: 'add',
        name: '商品添加',
        component: _import('stock/goods/add'),
        meta: {role: ['商品添加']}
      },
      {
        path: 'update/:id',
        name: '商品修改',
        component: _import('stock/goods/update'),
        hidden: true,
        meta: {role: ['商品修改']}
      },
      {
        path: 'examinegoods',
        name: '商品审核',
        component: _import('stock/goods/examinegoods'),
        meta: { role: ['商品审核'] }
      },]
  },
  {
    path: '/stock/retail',
    beforeEnter: (to, from, next) => {
      setMenu(6)
      next()
    },
    type: 6,
    component: Layout,
    icon: 'tubiao',
    name: '零售商品管理',
    meta: {role: ['零售商品列表', '零售商品添加', '零售商品修改', '零售商品导入', '零售商品分类']},
    children: [{
      path: 'index',
      name: '零售商品列表',
      component: _import('stock/retail/index'),
      meta: {role: ['零售商品列表']}
    },
      {
        path: 'category',
        name: '零售商品分类',
        component: _import('stock/retail/categoryTree'),
        meta: {role: ['零售商品分类']}
      },
      {
        path: 'add',
        name: '零售商品添加',
        component: _import('stock/retail/add'),
        meta: {role: ['零售商品添加']}
      },
      {
        path: 'import',
        name: '零售商品导入',
        component: _import('stock/retail/import'),
        meta: { role: ['零售商品导入'] }
      },
      {
        path: 'update/:id',
        name: '零售商品修改',
        component: _import('stock/retail/update'),
        hidden: true,
        meta: {role: ['零售商品修改']}
      }]
  },
  {
    path: '/stock/inverntory',
    beforeEnter: (to, from, next) => {
      setMenu(6)
      next()
    },
    type: 6,
    component: Layout,
    icon: 'tubiao',
    name: '库存管理',
    meta: {},
    children: [{
      path: 'index',
      name: '库存列表',
      component: _import('stock/inverntory/index'),
      // meta: { role: ['零售商品列表'] }
    },
      {
        path: 'supplier',
        name: '供应商管理',
        component: _import('stock/inverntory/supplier'),
        // meta: { role: ['零售商品添加'] }
      },

      {
        path: 'history',
        name: '历史明细',
        hidden: true,
        component: _import('stock/inverntory/history')
        // meta: { role: ['零售商品导入'] }
      },
      {
        path: 'inhistory',
        name: '入库流水',
        component: _import('stock/inverntory/history')
        // meta: { role: ['零售商品导入'] }
      },

      {
        path: 'outhistory',
        name: '出库流水',
        component: _import('stock/inverntory/history'),
        // meta: { role: ['零售商品修改'] }
      },
      {
        path: 'inventory',
        name: '盘点',
        component: _import('stock/inverntory/inverntory'),
      },
      {
        path: 'pdadd',
        name: '新建盘点',
        component: _import('stock/inverntory/inverntoryAdd'),
        hidden: true
      }
    ]
  }, {
    path: '/settle',
    beforeEnter: (to, from, next) => {
      setMenu(4)
      next()
    },
    type: 4,
    component: Layout,
    icon: 'tubiao',
    redirect: 'noredirect',
    // noDropdown: true,
    name: '结算管理',
    meta: {role: ['结算配置列表', '集团结算配置', '门店结算配置', '门店结算配置修改', '未归档结算', '已归档结算']},
    children: [
      {
        path: 'settle/shop/configs',
        name: '结算配置列表',
        component: _import('transaction/settle/shopSettleConfigIndex'),
        meta: {role: ['结算配置列表']}
      },
      {
        path: 'settle/org/config',
        name: '集团结算配置',
        component: _import('transaction/settle/orgSettleConfig'),
        meta: {role: ['集团结算配置']}
      },
      {
        path: 'settle/shop/config',
        name: '门店结算配置添加',
        hidden: true,
        component: _import('transaction/settle/shopSettleConfig'),
        meta: {role: ['门店结算配置添加']}
      },
      {
        path: 'settle/shop/config/:id',
        name: '门店结算配置修改',
        component: _import('transaction/settle/shopSettleConfig'),
        hidden: true,
        meta: {role: ['门店结算配置修改']}
      },
      {
        path: 'settle/do',
        name: '未归档结算',
        component: _import('transaction/settle/doSettle'),
        meta: {role: ['未归档结算']}
      },
      {
        path: 'settled',
        name: '已归档结算',
        component: _import('transaction/settle/settled'),
        meta: {role: ['已归档结算']}
      }
    ]
  },
]
