import {
  login,
  getInfo,
  register
} from '@/api/login'
import {
  getToken,
  setToken,
  removeToken
} from '@/utils/auth'
import { Message } from 'element-ui'

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: undefined,
    type: '',
    orgId: '',
    shopIds: []
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_TYPE: (state, type) => {
      state.type = type
    },
    SET_ORGID: (state, orgId) => {
      state.orgId = orgId
    },
    SET_SHOPIDS: (state, shopIds) => {
      state.shopIds = shopIds
    },
    SET_USER: (state, user) => {
      state = Object.assign(state, user)
    }
  },

  actions: {
    // 登录
    Login({
      commit
    }, userInfo) {
      userInfo['username'] = userInfo.username.trim()
      return new Promise((resolve, reject) => {
        login(userInfo).then(response => {
          if (response.code === '200') {
            const data = response.result
            if (data.type === 'ca') {
              Message({
                message: '收银员不可登陆管理系统！',
                type: 'error',
                duration: 2 * 1000
              })
            } else {
              setToken(data.token)
              commit('SET_USER', data)
              commit('SET_ROLES', data.permissionGroups)
              resolve(data)
            }
          }
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({
      commit,
      state
    }) {
      return new Promise((resolve, reject) => {
        getInfo().then(response => {
          const data = response.result
          data['roles'] = data.permissionGroups
          commit('SET_USER', data)
          commit('SET_ROLES', data.permissionGroups)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 登出
    LogOut({
      commit,
      state
    }) {
      return new Promise((resolve, reject) => {
        commit('SET_TOKEN', '')
        commit('SET_ROLES', [])
        removeToken()
        resolve()
      })
    },

    // 前端 登出
    FedLogOut({
      commit
    }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    },
    // 注册
    Register({
      commit
    }, registerForm) {
      registerForm['username'] = registerForm.username.trim()
      registerForm['name'] = registerForm.name.trim()
      return new Promise((resolve, reject) => {
        register(registerForm).then(response => {
          if (response.code === '200') {
            resolve()
          } else {
            reject(new Error(response.message))
          }
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
